<?php
/*
 *
 * - PopojiCMS Front End File
 *
 * - File : reservasi.php
 * - Version : 1.0
 * - Author : Jenuar Dalapang
 * - License : MIT License
 *
 *
 * Ini adalah file php yang di gunakan untuk menangani proses di bagian depan untuk halaman kontak.
 * This is a php file for handling front end process for reservasi page.
 *
*/

/**
 * Router untuk memproses request $_POST[] komentar.
 *
 * Router for process request $_POST[] comment.
 *
*/
$router->match('GET|POST', '/reservasi', function() use ($core, $templates) {
	$alertmsg = '';
	$lang = $core->setlang('contact', WEB_LANG);
	if (!empty($_POST)) {
		$core->poval->validation_rules(array(
			'reservasi_name' => 'required|max_len,100|min_len,3',
			'reservasi_email' => 'required|valid_email',
			'reservasi_phone' => 'required|max_len,255|min_len,6',
			'reservasi_type' => 'required|max_len,10|min_len,3',
			'reservasi_person' => 'required|max_len,10|min_len,1'
		));
		$core->poval->filter_rules(array(
			'reservasi_name' => 'trim|sanitize_string',
			'reservasi_email' => 'trim|sanitize_string',
			'reservasi_phone' => 'trim|sanitize_email',
			'reservasi_type' => 'trim|sanitize_string',
			'reservasi_person' => 'trim|sanitize_string'
		));
		$validated_data = $core->poval->run($_POST);
		if ($validated_data === false) {
			$alertmsg = '<div id="reservasi-form-result">
				<div class="alert alert-warning" role="alert">
					<button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>
					Reservasi gagal dikirim, silahkan lengkapi data form Anda.
				</div>
			</div>';
		} else {
			$website_name = $core->posetting[0]['value'];
			$website_url = $core->posetting[1]['value'];
			$reservasi_name = $_POST['reservasi_name'];
			$reservasi_phone = $_POST['reservasi_phone'];
			$email = $_POST['reservasi_email'];
			$reservasi_type = $_POST['reservasi_type'];
			$reservasi_person = $_POST['reservasi_person'];
			$subject = "Email Reservation For $website_name";
			$from = $core->posetting[5]['value'];
			$message = "<html>
				<body>
					Hi $reservasi_name,<br />
					Terima kasih telah melakukan reservasi untuk $reservasi_type, kami akan segera memprosesnya dan menginformasikannya lagi kepada Anda.<br /><br />
					--------------------<br /><br />
					Detail reservasi: <br /><br />
					Name: $reservasi_name <br />
					Email: $email <br />
					Phone : $reservasi_phone <br />
					Type : $reservasi_type <br />
					Person: $reservasi_person <br /><br />
					--------------------<br /><br />
					Best Regards,<br />
					$website_name
				</body>
			</html>";
			if ($core->posetting[23]['value'] != 'SMTP') {
				$poemail = new PoEmail;
				$send = $poemail
					->setOption(
						array(
							messageType => 'html'
						)
					)
					->to($email)
					->subject($subject)
					->message($message)
					->from($from)
					->mail();
				
				$poemail2 = new PoEmail;
				$send2 = $poemail2
					->setOption(
						array(
							messageType => 'html'
						)
					)
					->to($from)
					->subject($subject)
					->message($message)
					->from($from)
					->mail();
			} else {
				$core->pomail->isSMTP();
				$core->pomail->SMTPDebug = 0;
				$core->pomail->Debugoutput = 'html';
				$core->pomail->Host = $core->posetting[24]['value'];
				$core->pomail->Port = $core->posetting[27]['value'];
				$core->pomail->SMTPAuth = true;
				$core->pomail->SMTPSecure = 'ssl';
				$core->pomail->Username = $core->posetting[25]['value'];;
				$core->pomail->Password = $core->posetting[26]['value'];
				$core->pomail->setFrom($core->posetting[5]['value'], $core->posetting[0]['value']);
				$core->pomail->addAddress($email, $reservasi_name);
				$core->pomail->addAddress($from, $website_name);
				$core->pomail->IsHTML(true);
				$core->pomail->Subject = $subject;
				$core->pomail->Body = $message;
				$core->pomail->send();
			}
			unset($_POST);
			$alertmsg = '<div id="reservasi-form-result">
				<div class="alert alert-success" role="alert">
					<button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>
					Reservasi Anda telah kami terima dan akan segera diproses. Terima kasih.
				</div>
			</div>';
		}
	}
	$info = array(
		'page_title' => 'Reservasi',
		'page_desc' => $core->posetting[2]['value'],
		'page_key' => $core->posetting[3]['value'],
		'social_mod' => 'Reservasi',
		'social_name' => $core->posetting[0]['value'],
		'social_url' => $core->posetting[1]['value'],
		'social_title' => $core->posetting[0]['value'],
		'social_desc' => $core->posetting[2]['value'],
		'social_img' => $core->posetting[1]['value'].'/'.DIR_INC.'/images/favicon.png',
		'alertmsg' => $alertmsg
	);
	$adddata = array_merge($info, $lang);
	$templates->addData(
		$adddata
	);
	echo $templates->render('reservasi', compact('lang'));
});